function varargout = ayuda_datos_generales(varargin)
% AYUDA_DATOS_GENERALES M-file for ayuda_datos_generales.fig
%      AYUDA_DATOS_GENERALES, by itself, creates a new AYUDA_DATOS_GENERALES or raises the existing
%      singleton*.
%
%      H = AYUDA_DATOS_GENERALES returns the handle to a new AYUDA_DATOS_GENERALES or the handle to
%      the existing singleton*.
%
%      AYUDA_DATOS_GENERALES('CALLBACK',hObject,eventData,handles,...) calls the local
%      function named CALLBACK in AYUDA_DATOS_GENERALES.M with the given input arguments.
%
%      AYUDA_DATOS_GENERALES('Property','Value',...) creates a new AYUDA_DATOS_GENERALES or raises the
%      existing singleton*.  Starting from the left, property value pairs are
%      applied to the GUI before ayuda_datos_generales_OpeningFunction gets called.  An
%      unrecognized property name or invalid value makes property application
%      stop.  All inputs are passed to ayuda_datos_generales_OpeningFcn via varargin.
%
%      *See GUI Options on GUIDE's Tools menu.  Choose "GUI allows only one
%      instance to run (singleton)".
%
% See also: GUIDE, GUIDATA, GUIHANDLES
% Copyright 2002-2003 The MathWorks, Inc.
% Edit the above text to modify the response to help ayuda_datos_generales
% Last Modified by GUIDE v2.5 25-Mar-2002 12:19:15

%DEFINICIÓN DE LA FUNCIÓN
%Cuadro de ayuda que aparece una vez que se pulsa Ayuda en la pantalla
%donde se solicita que se introduzca el nombre del archivo, tasa de
%muestreo, número de canales.....

% Begin initialization code - DO NOT EDIT
gui_Singleton = 1;
gui_State = struct('gui_Name',       mfilename, ...
                   'gui_Singleton',  gui_Singleton, ...
                   'gui_OpeningFcn', @ayuda_datos_generales_OpeningFcn, ...
                   'gui_OutputFcn',  @ayuda_datos_generales_OutputFcn, ...
                   'gui_LayoutFcn',  [] , ...
                   'gui_Callback',   []);
if nargin && ischar(varargin{1})
    gui_State.gui_Callback = str2func(varargin{1});
end

if nargout
    [varargout{1:nargout}] = gui_mainfcn(gui_State, varargin{:});
else
    gui_mainfcn(gui_State, varargin{:});
end
% End initialization code - DO NOT EDIT


% --- Executes just before ayuda_datos_generales is made visible.
function ayuda_datos_generales_OpeningFcn(hObject, eventdata, handles, varargin)
% This function has no output args, see OutputFcn.
% hObject    handle to figure
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
% varargin   command line arguments to ayuda_datos_generales (see VARARGIN)

% Choose default command line output for ayuda_datos_generales
handles.output = hObject;

% Update handles structure
guidata(hObject, handles);

% UIWAIT makes ayuda_datos_generales wait for user response (see UIRESUME)
% uiwait(handles.figure1);


% --- Outputs from this function are returned to the command line.
function varargout = ayuda_datos_generales_OutputFcn(hObject, eventdata, handles) 
% varargout  cell array for returning output args (see VARARGOUT);
% hObject    handle to figure
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Get default command line output from handles structure
varargout{1} = handles.output;
